Class: Red::BuildError::NoSpecificRescue
- Inherits:
-
BuildError
- Object
- BuildError
- Red::BuildError::NoSpecificRescue
- Defined in:
- lib/red/errors.rb
Overview
Raised when an Error class is passed to rescue.
Raised when an Error class is passed to rescue.